.. toctree::
   :caption: Getting Started
   :hidden:

   Introduction <self>
   Install jobflow <install>
   Tutorials <tutorials>

.. toctree::
   :caption: Information
   :hidden:

   changelog
   contributors
   contributing
   license
   jobflow on GitHub <https://github.com/materialsproject/jobflow>


.. toctree::
   :caption: Reference
   :maxdepth: -1
   :hidden:

   API <jobflow>
   genindex

============
Introduction
============

.. mdinclude:: ../../README.md
   :start-line: 7
